==> react-native-grid-library-1.0.3.tgz: package/README.md <==
<p align="left">
    <a href="https://www.npmjs.com/package/@logisticinfotech/react-native-grid"><img alt="npm version" src="https://img.shields.io/badge/npm-v1.0.2-green.svg"></a>
    <a href="https://www.npmjs.com/package/@logisticinfotech/react-native-grid"><img src="https://img.shields.io/badge/downloads-%3E1K-yellow.svg"></a>
    <a href="https://www.npmjs.com/package/@logisticinfotech/react-native-grid"<><img src="https://img.shields.io/badge/license-MIT-orange.svg"></a>
</p>

### React Native Grid

## Npm repo
https://www.npmjs.com/package/@logisticinfotech/react-native-grid

## Git repo
https://github.com/logisticinfotech/react-native-grid

# Guide

<!-- # Installation and Usage
Please check this blog for installation and usage [this link]() -->

![](RNGrid.png)

## Properties

### Basic

#### For Container

| Prop | Default | Type | Description |
| ------ | -------- | ----- | ------------- |
| height | Screen Height | `Number` | Height of the container. |
| isNested | false | `Bool` | True if Container is nested. |
| backgroundColor | white | `String` | Background color of Container. |
| style | null | `style` | Style of Container. |

#### For Square

| Prop | Default | Type | Description |
| ------ | -------- | ----- | ------------- |
| xSquares | 1 | `Number` | Number of squares you want horizontally.  |
| ySquares | 1 | `Number` | Number of squares you want vertically. |
| backgroundColor | #D3D3D3 | `String` | Background color of Square. |
| allowHeightExcess | false | `Bool` | Allow height access to square or not. |
| fullScreenWidth | false | `Bool` | Allow full screen width grid or not. |
| style | null | `style` | Style of Square. |

==> react-native-grid-library-1.0.4.tgz: package/README.md <==
<p align="left">
    <a href="https://www.npmjs.com/package/@logisticinfotech/react-native-grid"><img alt="npm version" src="https://img.shields.io/badge/npm-v1.0.2-green.svg"></a>
    <a href="https://www.npmjs.com/package/@logisticinfotech/react-native-grid"><img src="https://img.shields.io/badge/downloads-%3E1K-yellow.svg"></a>
    <a href="https://www.npmjs.com/package/@logisticinfotech/react-native-grid"<><img src="https://img.shields.io/badge/license-MIT-orange.svg"></a>
</p>

### React Native Grid

## Npm repo
https://www.npmjs.com/package/@logisticinfotech/react-native-grid

## Git repo
https://github.com/logisticinfotech/react-native-grid

# Guide

# Installation and Usage
Please check this blog for installation and usage [this link](https://www.logisticinfotech.com/blog/react-native-grid-library/)

![](RNGrid.png)

<!-- 

## Properties

### Basic

#### For Container

| Prop | Default | Type | Description |
| ------ | -------- | ----- | ------------- |
| height | Screen Height | `Number` | Height of the container. |
| isNested | false | `Bool` | True if Container is nested. |
| backgroundColor | white | `String` | Background color of Container. |
| style | null | `style` | Style of Container. |

#### For Square

| Prop | Default | Type | Description |
| ------ | -------- | ----- | ------------- |
| xSquares | 1 | `Number` | Number of squares you want horizontally.  |
| ySquares | 1 | `Number` | Number of squares you want vertically. |
| backgroundColor | #D3D3D3 | `String` | Background color of Square. |
| allowHeightExcess | false | `Bool` | Allow height access to square or not. |
| fullScreenWidth | false | `Bool` | Allow full screen width grid or not. |
| style | null | `style` | Style of Square. | -->
